@@ -1,10 +1,10 @@
 import json
 from typing import Optional
 
-from aiiohttp import AiohttpSession
-from ai_openchat.model import Model
-from base.session import BaseSession
-from utils.token import validate_token
+from .aiiohttp import AiohttpSession
+from .model import Model
+from .session import BaseSession
+from .token import validate_token
 
 
 class AsyncOpenAI:
